==> ejc-assistrmat-api-3.0.0-20221101.020733-293-sources.jar: com/ejianc/business/assist/rmat/vo/StoreNumVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.math.BigDecimal;


/**
 * 材料明细
 * 
 * @author generator
 * 
 */
public class StoreNumVO {
    private static final long serialVersionUID = 1L;

    private Long storeId; // 仓库主键
    private Long materialId; // 物料主键
    private Integer sourceType;// 材料来源,0-自购,1-租赁
    private Long orgId;// 组织主键
    private Long unitMId; // 计量单位id
    private Long unitId; // 计租单位id
    private BigDecimal transScale; // 转换系数
    private BigDecimal storeNum; // 库存可用数量
    private BigDecimal assistNum; // 计租数量
    private BigDecimal deviationRate; // 偏差率

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getStoreNum() {
        return storeNum;
    }

    public void setStoreNum(BigDecimal storeNum) {
        this.storeNum = storeNum;
    }

    public BigDecimal getAssistNum() {
        return assistNum;
    }

    public void setAssistNum(BigDecimal assistNum) {
        this.assistNum = assistNum;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
}

==> ejc-assistrmat-api-3.0.0-20221208.070553-335-sources.jar: com/ejianc/business/assist/rmat/vo/StoreNumVO.java <==
package com.ejianc.business.assist.rmat.vo;

import java.math.BigDecimal;


/**
 * 材料明细
 * 
 * @author generator
 * 
 */
public class StoreNumVO {
    private static final long serialVersionUID = 1L;

    private Long storeId; // 仓库主键
    private Long materialId; // 物料主键
    private Integer sourceType;// 材料来源,0-自购,1-租赁
    private Long orgId;// 组织主键
    private Long unitMId; // 计量单位id
    private Long unitId; // 计租单位id
    private BigDecimal transScale; // 转换系数
    private BigDecimal storeNum; // 库存可用数量
    private BigDecimal assistNum; // 计租数量
    private BigDecimal deviationRate; // 偏差率
    private BigDecimal rentNum;//租出出库使用数量

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }

    public BigDecimal getStoreNum() {
        return storeNum;
    }

    public void setStoreNum(BigDecimal storeNum) {
        this.storeNum = storeNum;
    }

    public BigDecimal getAssistNum() {
        return assistNum;
    }

    public void setAssistNum(BigDecimal assistNum) {
        this.assistNum = assistNum;
    }

    public BigDecimal getDeviationRate() {
        return deviationRate;
    }

    public void setDeviationRate(BigDecimal deviationRate) {
        this.deviationRate = deviationRate;
    }
}
